==> material__tab-indicator-1.1.0.jar: META-INF/resources/webjars/material__tab-indicator/1.1.0/foundation.d.ts <==
/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
import { MDCFoundation } from '@material/base/foundation';
import { MDCTabIndicatorAdapter } from './adapter';
export declare abstract class MDCTabIndicatorFoundation extends MDCFoundation<MDCTabIndicatorAdapter> {
    static readonly cssClasses: {
        ACTIVE: string;
        FADE: string;
        NO_TRANSITION: string;
    };
    static readonly strings: {
        CONTENT_SELECTOR: string;
    };
    static readonly defaultAdapter: MDCTabIndicatorAdapter;
    constructor(adapter?: Partial<MDCTabIndicatorAdapter>);
    computeContentClientRect(): ClientRect;
    abstract activate(previousIndicatorClientRect?: ClientRect): void;
    abstract deactivate(): void;
}
export default MDCTabIndicatorFoundation;

==> material__tab-indicator-8.0.0.jar: META-INF/resources/webjars/material__tab-indicator/8.0.0/foundation.d.ts <==
/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
import { MDCFoundation } from '@material/base/foundation';
import { MDCTabIndicatorAdapter } from './adapter';
export declare abstract class MDCTabIndicatorFoundation extends MDCFoundation<MDCTabIndicatorAdapter> {
    static get cssClasses(): {
        ACTIVE: string;
        FADE: string;
        NO_TRANSITION: string;
    };
    static get strings(): {
        CONTENT_SELECTOR: string;
    };
    static get defaultAdapter(): MDCTabIndicatorAdapter;
    constructor(adapter?: Partial<MDCTabIndicatorAdapter>);
    computeContentClientRect(): ClientRect;
    abstract activate(previousIndicatorClientRect?: ClientRect): void;
    abstract deactivate(): void;
}
export default MDCTabIndicatorFoundation;
